]> git.sesse.net Git - nageru/blobdiff - mixer.h
Send audio all the way through to the encoder and muxer.
[nageru] / mixer.h
diff --git a/mixer.h b/mixer.h
index f4ea5c9cd6b41b57cbbec2bae3ce867100aef222..9b631e4766071d35e6f0d215cd3f4442f46cdf2e 100644 (file)
--- a/mixer.h
+++ b/mixer.h
@@ -113,9 +113,10 @@ private:
                QSurface *surface;
                QOpenGLContext *context;
 
-               bool new_data_ready = false;  // Whether new_frame contains anything.
+               bool new_data_ready = false;  // Whether new_frame and new_frame_audio contains anything.
                RefCountedFrame new_frame;
                GLsync new_data_ready_fence;  // Whether new_frame is ready for rendering.
+               std::vector<float> new_frame_audio;
                std::condition_variable new_data_ready_changed;  // Set whenever new_data_ready is changed.
                Resampler *resampler = nullptr;
        };